
# Slot: started at time




URI: [ks:started_at_time](https://w3id.org/linkml/tests/kitchen_sink/started_at_time)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Date](Date.md)

## Parents


## Children


## Used by

 * [BirthEvent](BirthEvent.md)
 * [EmploymentEvent](EmploymentEvent.md)
 * [Event](Event.md)
 * [FamilialRelationship](FamilialRelationship.md)
 * [MarriageEvent](MarriageEvent.md)
 * [MedicalEvent](MedicalEvent.md)
 * [Relationship](Relationship.md)
 * [Activity](Activity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | prov:startedAtTime |

